@@ -1,10 +1,10 @@
 package Net::DNS::RR::KEY;
 
 #
-# $Id: KEY.pm 1339 2015-04-16 13:01:17Z willem $
+# $Id: KEY.pm 1381 2015-08-25 07:36:09Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1339 $)[1];
+$VERSION = (qw$LastChangedRevision: 1381 $)[1];
 
 
 use strict;
@@ -17,7 +17,7 @@ Net::DNS::RR::KEY - DNS KEY resource record
 =cut
 
 
-sub defaults() {			## specify RR attribute default values
+sub _defaults {				## specify RR attribute default values
 	my $self = shift;
 
 	$self->algorithm(1);
