@@ -1,10 +1,10 @@
 package Net::DNS::RR::PTR;
 
 #
-# $Id: PTR.pm 1390 2015-09-11 11:42:11Z willem $
+# $Id: PTR.pm 1406 2015-10-05 08:25:49Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1390 $)[1];
+$VERSION = (qw$LastChangedRevision: 1406 $)[1];
 
 
 use strict;
@@ -56,7 +56,7 @@ sub ptrdname {
 	my $self = shift;
 
 	$self->{ptrdname} = new Net::DNS::DomainName1035(shift) if scalar @_;
-	$self->{ptrdname}->name if defined wantarray && $self->{ptrdname};
+	$self->{ptrdname}->name if $self->{ptrdname};
 }
 
 
