@@ -1,10 +1,10 @@
 package Net::DNS::RR::PX;
 
 #
-# $Id: PX.pm 1390 2015-09-11 11:42:11Z willem $
+# $Id: PX.pm 1406 2015-10-05 08:25:49Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1390 $)[1];
+$VERSION = (qw$LastChangedRevision: 1406 $)[1];
 
 
 use strict;
@@ -72,7 +72,7 @@ sub map822 {
 	my $self = shift;
 
 	$self->{map822} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{map822}->name if defined wantarray && $self->{map822};
+	$self->{map822}->name if $self->{map822};
 }
 
 
@@ -80,7 +80,7 @@ sub mapx400 {
 	my $self = shift;
 
 	$self->{mapx400} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{mapx400}->name if defined wantarray && $self->{mapx400};
+	$self->{mapx400}->name if $self->{mapx400};
 }
 
 
