@@ -15,10 +15,10 @@ sub UNITCHECK {				## restore %SIG after compilation
 package Net::DNS::RR::SIG;
 
 #
-# $Id: SIG.pm 1425 2015-11-02 05:58:15Z willem $
+# $Id: SIG.pm 1456 2016-02-17 13:34:00Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1425 $)[1];
+$VERSION = (qw$LastChangedRevision: 1456 $)[1];
 
 
 use strict;
@@ -36,18 +36,18 @@ use integer;
 use Carp;
 use Time::Local;
 
-eval { require MIME::Base64 };
+eval 'require MIME::Base64';
 
 use Net::DNS::Parameters;
 
 use constant DEBUG => 0;
 
-use constant UTIL => defined eval { require Scalar::Util; };
+use constant UTIL => defined eval 'require Scalar::Util';
 
-use constant PRIVATE => defined eval { require Net::DNS::SEC::Private; };
+use constant PRIVATE => defined eval 'require Net::DNS::SEC::Private';
 
-use constant DSA => defined eval { require Net::DNS::SEC::DSA; };
-use constant RSA => defined eval { require Net::DNS::SEC::RSA; };
+use constant DSA => defined eval 'require Net::DNS::SEC::DSA';
+use constant RSA => defined eval 'require Net::DNS::SEC::RSA';
 
 use constant DNSSEC => PRIVATE && ( RSA || DSA );
 
@@ -708,8 +708,8 @@ that comes with the ISC BIND distribution.
 The optional remaining arguments consist of ( name => value ) pairs
 as follows:
 
-	sigin  => 20151201010101,	# signature inception
-	sigex  => 20151201011101,	# signature expiration
+	sigin  => 20161201010101,	# signature inception
+	sigex  => 20161201011101,	# signature expiration
 	sigval => 10,			# validity window (minutes)
 
 The sigin and sigex values may be specified as Perl time values or as
