@@ -1,10 +1,10 @@
 package Net::DNS::RR::SOA;
 
 #
-# $Id: SOA.pm 1390 2015-09-11 11:42:11Z willem $
+# $Id: SOA.pm 1408 2015-10-06 20:35:56Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1390 $)[1];
+$VERSION = (qw$LastChangedRevision: 1408 $)[1];
 
 
 use strict;
@@ -85,7 +85,7 @@ sub mname {
 	my $self = shift;
 
 	$self->{mname} = new Net::DNS::DomainName1035(shift) if scalar @_;
-	$self->{mname}->name if defined wantarray && $self->{mname};
+	$self->{mname}->name if $self->{mname};
 }
 
 
@@ -93,7 +93,7 @@ sub rname {
 	my $self = shift;
 
 	$self->{rname} = new Net::DNS::Mailbox1035(shift) if scalar @_;
-	$self->{rname}->address if defined wantarray && $self->{rname};
+	$self->{rname}->address if $self->{rname};
 }
 
 
@@ -106,7 +106,7 @@ sub serial {
 	return $self->{serial} = 0 + $value if _ordered( $self->{serial}, $value );
 
 	# unwise to assume 32-bit arithmetic, or that integer overflow goes unpunished
-	my $serial = 0xFFFFFFFF & ( $self->{serial} || 0 );
+	my $serial = ( 0 + $self->{serial} ) & 0xFFFFFFFF;
 	return $self->{serial} = $serial ^ 0xFFFFFFFF if ( $serial & 0x7FFFFFFF ) == 0x7FFFFFFF;    # wrap
 	return $self->{serial} = $serial + 1;			# increment
 }
