@@ -1,10 +1,10 @@
 package Net::DNS::RR::TLSA;
 
 #
-# $Id: TLSA.pm 1370 2015-07-01 13:48:40Z willem $
+# $Id: TLSA.pm 1456 2016-02-17 13:34:00Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1370 $)[1];
+$VERSION = (qw$LastChangedRevision: 1456 $)[1];
 
 
 use strict;
@@ -19,10 +19,10 @@ Net::DNS::RR::TLSA - DNS TLSA resource record
 
 use integer;
 
-use constant BABBLE => defined eval { require Digest::BubbleBabble; };
+use constant BABBLE => defined eval 'require Digest::BubbleBabble';
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -34,7 +34,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	return '' unless defined $self->{certbin};
@@ -42,17 +42,17 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless defined $self->{certbin};
 	my @babble = BABBLE ? ( join '', ';', $self->babble, "\n" ) : ();
 	my @cert = split /(\S{64})/, $self->cert;
-	my @rdata = $self->usage, $self->selector, $self->matchingtype, @cert, @babble;
+	my @rdata = ( $self->usage, $self->selector, $self->matchingtype, @cert, @babble );
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->usage(shift);
@@ -161,6 +161,8 @@ presented by the server will be matched against the association data.
 8-bit integer value which specifies how the certificate association
 is presented.
 
+=head2 certificate
+
 =head2 cert
 
     $cert = $rr->cert;
